@@ -2,12 +2,12 @@
 
 #' Preference Selection
 #' 
-#' Evaluates a preference on a given dataset, i.e., 
+#' Evaluates a preference on a given data set, i.e., 
 #' returns the maximal elements of a data set for a given preference order.
 #' 
 #' @param df A data frame or, for a grouped preference selection, a grouped data frame. See below for details.
 #' @param pref The preference order constructed via \code{\link{complex_pref}} and \code{\link{base_pref}}. 
-#'             All variables occuring in the definition of \code{pref} must be either columns of the data frame \code{df} 
+#'             All variables occurring in the definition of \code{pref} must be either columns of the data frame \code{df} 
 #'             or variables/functions of the environment where \code{pref} was defined.
 #' @param ... Additional (optional) parameters for top(-level)-k selections:
 #'  \describe{
@@ -19,15 +19,18 @@
 #'      \code{at_least}. In contrast to top-k, this is deterministic.}
 #'     \item{\code{top_level}}{A \code{top_level} value of k returns all tuples from the k-best levels. See below for the definition of a level.}
 #'     \item{\code{and_connected}}{Logical value, which is only relevant if more than one of the above \{\code{top}, \code{at_least}, \code{top_level}\} 
-#'     values is given. Then \code{and_connected = TRUE} (which is the default) means that all top-conditions must hold for the returned tuples: 
+#'     values is given, otherwise it will be ignored. 
+#'     Then \code{and_connected = TRUE} (which is the default) means that all top-conditions 
+#'     must hold for the returned tuples: 
 #'     Let \code{cond1} and \code{cond2} be top-conditions like \code{top=2} or \code{top_level=3}, then
 #'     \code{psel([...], cond1, cond2)} is equivalent to the intersection of \code{psel([...], cond1)} and \code{psel([...], cond2)}. If we have
 #'     \code{and_connected = FALSE}, these conditions are or-connected. 
 #'     This corresponds to the union of \code{psel([...], cond1)} and \code{psel([...], cond2)}.}
 #'     \item{\code{show_level}}{Logical value. If \code{TRUE}, a column \code{.level} 
-#'     is added to the returned data frame, containing all level values (see below for details). 
-#'     This is only relevant if at least one of the \{\code{top}, \code{at_least}, \code{top_level}\} values is given. 
-#'     For \code{psel} this is \code{TRUE} by default, for \code{psel.indices} this is \code{FALSE} by default.}
+#'     is added to the returned data frame, containing all level values. 
+#'     If at least one of the \{\code{top}, \code{at_least}, \code{top_level}\} values are given,
+#'     then \code{show_level} is \code{TRUE} by default for the \code{psel} function. 
+#'     Otherwise, and for \code{psel.indices} in all cases, this option is \code{FALSE} by default.}
 #' }
 #' 
 #' @details
@@ -47,16 +50,20 @@
 #' 
 #' \itemize{
 #' \item{All the maxima of a data set w.r.t. a preference have level 1.}
-#' \item{The maxima of the remainder, i.e., the dataset without the level 1 maxima, have level 2.}
+#' \item{The maxima of the remainder, i.e., the data set without the level 1 maxima, have level 2.}
 #' \item{The n-th iteration of "Take the maxima from the remainder" leads to tuples of level n.}
 #' }
 #' 
 #' By default, \code{psel.indices} does not return the level values. By setting \code{show_level = TRUE} this function
 #' returns a data frame with the columns '.indices' and '.level'. 
+#' Note that, if none of the top-k values \{\code{top}, \code{at_least}, \code{top_level}\} is set,
+#' then all level values are equal to 1. 
 #' 
-#' By definition, a top-k preference selection is non-deterministic. A top-1 query of two equivalent tuples (equivalence according to \code{pref})
-#' can return on both of these tuples. E.g., for tuples {(a=1, b=1), (a=1, b=2)} a \code{top=1} preference selection w.r.t. \code{low(a)} preference can return
-#' either the 'b=1' or the 'b=2' tuple. 
+#' By definition, a top-k preference selection is non-deterministic. 
+#' A top-1 query of two equivalent tuples (equivalence according to \code{pref})
+#' can return on both of these tuples. 
+#' For example, a \code{top=1} preference selection on the tuples {(a=1, b=1), (a=1, b=2)}
+#' w.r.t. \code{low(a)} preference can return either the 'b=1' or the 'b=2' tuple. 
 #' 
 #' On the contrary, a preference selection using \code{at_least} is deterministic by adding all tuples having the same level as the worst level 
 #' of the corresponding top-k query. This means, the result is filled with all tuples being not worse than the top-k result. 
@@ -68,32 +75,32 @@
 #' 
 #' @section Grouped Preference Selection:
 #' 
-#' With \code{psel} it is also possible to perform a preference selection where the maxima are calculated for every group seperately. 
+#' Using \code{psel} it is also possible to perform a preference selection where the maxima are calculated for every group separately. 
 #' The groups have to be created with \code{\link{group_by}} from the dplyr package. The preference selection preserves the grouping, i.e.,
 #' the groups are restored after the preference selection.
 #' 
 #' For example, if the \code{summarize} function from dplyr is applied to
 #' \code{psel(group_by(...), pref)}, the summarizing is done for the set of maxima of each group. 
-#' This can be used to e.g., calculate the number of maxima in each group, see examples below.
+#' This can be used to e.g., calculate the number of maxima in each group, see the examples below.
 #' 
 #' A \{\code{top}, \code{at_least}, \code{top_level}\} preference selection
-#' is applied to each group seperately.
+#' is applied to each group separately.
 #' A \code{top=k} selection returns the k best tuples for each group. 
 #' Hence if there are 3 groups in \code{df}, each containing at least 2 elements, 
 #' and we have \code{top = 2}, then 6 tuples will be returned.
 #' 
 #' @section Parallel Computation:
 #' 
-#' On multicore machines the preference selection can be run in parellel using a divide-and-conquer approach. 
-#' Note that, depending on the data set, this is not faster thean a single-threaded computation in all cases.
-#' To active parallel compuation within rPref:
+#' On multi-core machines the preference selection can be run in parallel using a divide-and-conquer approach. 
+#' Depending on the data set, this may be faster than a single-threaded computation.
+#' To activate parallel computation within rPref the following option has to be set:
 #' 
 #' \code{options(rPref.parallel = TRUE)}
 #' 
 #' If this option is not set, rPref will use single-threaded computation by default.
 #' 
 #' @seealso See \code{\link{complex_pref}} on how to construct a Skyline preference. 
-#' See \code{\link{plot_front}} on how to plot the pareto front of a Skyline.
+#' See \code{\link{plot_front}} on how to plot the Pareto front of a Skyline.
 #' 
 #' 
 #' @name psel
@@ -127,7 +134,13 @@ psel <- function(df, pref, ...) {
   is_top <- any(names(vars) %in% c('top', 'at_least', 'top_level'))
   
   # Store actual show_level value
-  show_level <- is_top && (is.null(vars$show_level) || isTRUE(vars$show_level)) # FALSE by Default
+  if (is_top) {
+    # top value is set => show_level is TRUE by Default
+    show_level <- is.null(vars$show_level) || isTRUE(vars$show_level)
+  } else {
+    # top value is not set => show_level is FALSE by Default
+    show_level <- isTRUE(vars$show_level)
+  }
   vars$show_level <- show_level
   
   # Call psel.indices with all parameters from ...
@@ -165,10 +178,10 @@ psel.indices <- function(df, pref, ...) {
   if (!is.data.frame(df))          stop("Preference selection needs a data.frame as first argument.")
   if (!is.actual.preference(pref)) stop("Preference selection needs a preference as second argument.")
   
-  # Check if grouped data.table (currently not implemented, only grouped dataframes work fine)
+  # Check if grouped data.table (currently not implemented, only grouped data frames work fine)
   if (dplyr::is.grouped_dt(df)) {
     df <- group_by_(as.data.frame(df), .dots = attr(df, 'vars'))
-    warning("Grouped preference selection is only possible for grouped dataframes. The input was converted to a grouped dataframe.")
+    warning("Grouped preference selection is only possible for grouped data frames. The input was converted to a grouped data frame.")
   }
     
   # ** Get all special arguments for top-k selections
@@ -180,11 +193,12 @@ psel.indices <- function(df, pref, ...) {
     
   is_top <- any(c('top', 'at_least', 'top_level') %in% names(vars))
   
+  # Show-level operates indepndant of is_top!
+  show_level    <- isTRUE(vars[['show_level']]) # FALSE by Default (for psel.indices)
+  
   if (is_top) { 
-    
     # Logical options
     and_connected <- isTRUE(vars[['and_connected']]) || is.null(vars[['and_connected']])  # TRUE by default
-    show_level    <- isTRUE(vars[['show_level']]) # FALSE by Default (for psel.indices)
     
     # No defaults, but value -1 if null
     top       <- check.singleint.null2minus(vars[['top']],       'top')
@@ -205,7 +219,7 @@ psel.indices <- function(df, pref, ...) {
   if ((length(vars) > 0 && is.null(names(vars))) || ('' %in% names(vars)))
     warning("Unnamed arguments were passed to '...' in psel. They will be ignored.")
   
-  # ** Calculcalate score/serial pref
+  # ** Calculate score/serial pref
  
   # Precalculate score values for given preference, get_corevals must be called before serialize!
   scores <- pref$get_scorevals(1, df)$scores
@@ -233,8 +247,12 @@ psel.indices <- function(df, pref, ...) {
       res <- grouped_pref_sel_impl(df, scores, pref_serial, Npar, alpha) 
     }
     
-    # All C indices start at 0, and all R indices start at 1
-    return(res + 1)
+    if (!show_level) # just return indices
+      # All C indices start at 0, and all R indices start at 1
+      return(res + 1)
+    else
+      # Add level values for is_top = FALSE, i.e., all level values are 1
+      return(data.frame(.indices = res + 1, .level = 1))
     
   } else {
     
