@@ -3,14 +3,15 @@
 #' For a given preference this shows the \code{PREFERRING} clause of a database query in different SQL dialects which support preferences.
 #' 
 #' @param p A preference.
-#' @param dialect The preference query dialect, which determines the syntax of the returned query. This has to be one of the following:
+#' @param dialect The preference query dialect, which determines the syntax of the returned query. 
+#'        This has to be one of the following (not case sensitive):
 #' \describe{
 #'    \item{\code{'EXASOL'}:}{Syntax of the "Skyline" feature of the commercial database EXASOL EXASolution 5.}
 #'    \item{\code{'Preference SQL'} or \code{'PSQL'}:}{Syntax of the Preference SQL system. 
 #'      This is a research prototype developed at the Chair of Databases and Information Systems of the University of Augsburg. 
 #'      See references for details.}
 #' }
-#' @param df Optional parameter to specifiy a dataframe on which the preference operates causing a partial evaluation. See \code{\link{show.pref}} for details.
+#' @param df Optional parameter to specify a data frame on which the preference operates causing a partial evaluation. See \code{\link{show.pref}} for details.
 #'     
 #' @details 
 #' 
@@ -42,44 +43,47 @@
 #' @export
 show.query <- function(p, dialect = 'EXASOL', df = NULL) {
  
-  if (dialect == "PSQL" || dialect == "PreferenceSQL") dialect = PSQL
+  # Make parameter "dialect" not case sensitive
+  dialect <- tolower(dialect)
+  
+  if (dialect == "psql" || dialect == "preferencesql") dialect <- PSQL
   
   # Check dialect
   if (!(dialect %in% c(EXA, PSQL))) stop(paste0('The dialect "', dialect, '" is unknown.'))
   
   # Check for empty -> return empty string
-  if (is.emptypref(p)) return("")
+  if (is.empty_pref(p)) return("")
   
   # Return PREFERRING-clause
   return(paste0('PREFERRING ', show_pref_sql(p, dialect, 'PREF', get_static_terms(df)))) # parent node "PREF" means root node
 }
 
 
-#' Partial Evaluation and String Output of Preferences
+#' Partial Evaluation and String/Expression Output of Preferences
 #' 
 #' Functions to substitute variables and functions in preferences 
 #' which can be calculated before the preference is evaluated on a data frame.
-#' This is especially used for the string output of preferences.
+#' This is especially used for the string/expression output of preferences.
 #' 
-#' @param p,x The preference to be shown or partially evaluated.
-#' @param df (optional) A dataframe on which the preference operates.
-#' @param ... Optional arguments passed to \code{as.character}.
+#' @param p The preference to be shown or partially evaluated.
+#' @param df (optional) A data frame on which the preference operates.
 #' 
 #' @details The function \code{pref.str} (or \code{as.character(p)} for a preference \code{p}) returns the preference string 
 #' while \code{show.pref} outputs it directly to the console, preceded by \code{'[Preference]'}.
-#' If \code{df} is specified, then a partial evaluation of the preference is done before converting it to a string.
+#' If \code{df} is specified, then a partial evaluation of the preference is done before converting it to a string. 
+#' With \code{as.expression(p)} the R code for constructing a given preference is given.
 #' 
-#' The function \code{eval.pref} (with given dataframe \code{df}) partially evaluates the internal preference expression and 
+#' The function \code{eval.pref} (with given data frame \code{df}) partially evaluates the internal preference expression and 
 #' returns again a preference object. All expressions in \code{p} are evaluated in the environment
 #' where \code{p} was defined, except the the column names in \code{df} (which are potential attributes in \code{p}) 
 #' and except the special variable \code{df__}, which accesses the entire data set (see \code{\link{psel}}).
-#' The content of the dataframe \code{df} does not matter; only \code{names(df)} is used to get the "free variables" in \code{p}.
+#' The content of the data frame \code{df} does not matter; only \code{names(df)} is used to get the "free variables" in \code{p}.
 #' 
 #' 
 #' @section Partial Evaluation Before String Output:
 #' 
-#' The functions \code{show.pref} and \code{pref.str} have the optional paramter \code{df}.
-#' If this paramter is given, these functions call \code{eval.pref} before they output or return the preference string.
+#' The functions \code{show.pref} and \code{pref.str} have the optional parameter \code{df}.
+#' If this parameter is given, these functions call \code{eval.pref} before they output or return the preference string.
 #' The following equalities hold:
 #' 
 #' \itemize{
@@ -87,15 +91,17 @@ show.query <- function(p, dialect = 'EXASOL', df = NULL) {
 #'   \item \code{show(eval.pref(p, df))} produces the same console output as \code{show.pref(p, df)}
 #' }
 #' 
+#' @seealso See \code{\link{general_pref}} for more utility functions for preferences.
+#' 
 #' @examples
 #' 
 #' f <- function(x) 2*x
 #' p <- true(cyl == f(1))
 #' 
-#' # prints 'cyl == f(x)'
+#' # prints 'true(cyl == f(1))'
 #' p
 #' 
-#' # prints 'cyl == 2'
+#' # prints 'true(cyl == 2)'
 #' show.pref(p, mtcars)
 #' eval.pref(p, mtcars)
 #' 
@@ -127,20 +133,16 @@ eval.pref <- function(p, df = NULL) {
   return(eval.pref.internal(p, df))
 }
 
-#' @export
-#' @rdname show.pref
-as.character.preference <- function(x, ...) x$get_str()
-
 # Get attributes of a data set as symbols
 get_static_terms <- function(df) {
-  # Get static terms (all attributes of dataset, if given)
+  # Get static terms (all attributes of data set, if given)
   if (!is.null(df)) return(lapply(names(df), as.symbol))
   else return(NULL)  
 }
 
-# Available Dialects
-EXA <- 'EXASOL'
-PSQL <- 'Preference SQL'
+# Available Dialects (in lower case)
+EXA <- 'exasol'
+PSQL <- 'preference sql'
 
 # Translation maps for operators
 PSQL_PREF_MAP = list('*'        = 'AND', 
@@ -156,13 +158,13 @@ EXASOL_PREF_MAP = list('*'        = 'PLUS',
                        'reverse'  = 'INVERSE')
 
 
-
+# Internal function for converting a preference to its sql representation
 show_pref_sql <- function(p, dialect, parent_op = '', static_terms = NULL) {
   
   if (dialect == EXA) use_map <- EXASOL_PREF_MAP
   else                use_map <- PSQL_PREF_MAP
   
-  if (is.basepref(p)) {
+  if (is.base_pref(p)) {
     return(show_base_pref(p, dialect, static_terms))
   } else if (is.reversepref(p)) { 
     if (dialect == EXA) # INVERSE is notated as prefix in EXASOL
@@ -170,7 +172,7 @@ show_pref_sql <- function(p, dialect, parent_op = '', static_terms = NULL) {
     else  # "DUAL" is notated as suffix in Preference SQL!
       return(paste0('(', show_pref_sql(p$p, dialect, static_terms = static_terms), ') ', use_map[['reverse']]))
       
-  } else if (is.complexpref(p)) {
+  } else if (is.binarycomplexpref(p)) {
     # usual complex preference (not inverse!)
     opchr <- use_map[[p$op]]
     # Check if operator is available in the given dialect
