@@ -1,15 +1,19 @@
 
+
 class pref {
 public:
-  int highest_id;
-
 	virtual bool cmp(int, int) = 0;
 	virtual bool eq(int, int) = 0;
+  
+  // Virtual desctructor, so that sub-destructors are called!
+  virtual ~pref() {};
 }; 
 
 class scorepref : public pref {
 public:
-  NumericVector data;
+  const NumericVector data;
+  
+  scorepref(const NumericVector& data) : data(data) {};
 
 	bool cmp(int i, int j);
 	bool eq(int i, int j);
@@ -19,11 +23,14 @@ class complexpref : public pref {
 public:
   pref *p1;
 	pref *p2;
+  
+  complexpref() : p1(0), p2(0) {};
+  ~complexpref();
 
 	bool eq(int i, int j);
 };
 
-// Common Superclass for Pareto and intersection 
+// Common superclass for Pareto and intersection 
 class productpref : public complexpref {};
 
 class pareto : public productpref {
@@ -49,10 +56,13 @@ public:
 class reversepref : public pref {
 public:
 	pref *p;
+  
+  reversepref() : p(0) {};
+  ~reversepref();
 
 	bool cmp(int i, int j);
 	bool eq(int i, int j);
 };
 
 // Derserialize preference 
-pref* CreatePreference(List, DataFrame&, int);
+pref* CreatePreference(const List& pref_lst, const DataFrame& scores);
